/***************************************************************************
*
*	File name : gpio_api.h
*	Function  : APIs of GPIO
*	Revision  :
*		08/06/2007	Nariai		First revision
*
****************************************************************************/
#ifndef	__GPIO_API_H__
#define	__GPIO_API_H__

// Port interrupt No.
#define	GPIO_INT_NO_0	0x00
#define	GPIO_INT_NO_1	0x01
#define	GPIO_INT_NO_2	0x02
#define	GPIO_INT_NO_3	0x03
#define	GPIO_INT_NO_4	0x04
#define	GPIO_INT_NO_5	0x05
#define	GPIO_INT_NO_6	0x06
#define	GPIO_INT_NO_7	0x07

// Port function
#define	GPIO_FUNCTION_0	0x00
#define	GPIO_FUNCTION_1	0x01
#define	GPIO_FUNCTION_2	0x02
#define	GPIO_FUNCTION_3	0x03

// Port I/O setting
#define	GPIO_IO_INPUT	0x00
#define	GPIO_IO_OUTPUT	0x01

// Port Data setting
#define	GPIO_DATA_0		0
#define	GPIO_DATA_1		1

// Union of port function select
typedef union {
	volatile unsigned short		CFP;

	volatile struct {
		unsigned char			CFP03;
		unsigned char			CFP47;
	} uc;

	volatile struct {
		unsigned short			CFPx0	: 2;
		unsigned short			CFPx1	: 2;
		unsigned short			CFPx2	: 2;
		unsigned short			CFPx3	: 2;
		unsigned short			CFPx4	: 2;
		unsigned short			CFPx5	: 2;
		unsigned short			CFPx6	: 2;
		unsigned short			CFPx7	: 2;
	} b;
} U_GPIO_FUNC_SEL;

// Union of port function select
typedef struct {
	void (*Int0)(void);
	void (*Int1)(void);
	void (*Int2)(void);
	void (*Int3)(void);
	void (*Int4)(void);
	void (*Int5)(void);
	void (*Int6)(void);
	void (*Int7)(void);
} T_GPIO_CFG;


/* ----- Read data from port ----- */

// P0x
#define	GpioReadPortDataP0x()		(EGPIO_P0_DATA)
#define	GpioReadPortDataP00()		(EGPIO_P0_DATA & EGPIO_P0_DATA_P00D)
#define	GpioReadPortDataP01()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P01D) >> 1)
#define	GpioReadPortDataP02()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P02D) >> 2)
#define	GpioReadPortDataP03()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P03D) >> 3)
#define	GpioReadPortDataP04()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P04D) >> 4)
#define	GpioReadPortDataP05()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P05D) >> 5)
#define	GpioReadPortDataP06()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P06D) >> 6)
#define	GpioReadPortDataP07()		((EGPIO_P0_DATA & EGPIO_P0_DATA_P07D) >> 7)

// P1x
#define	GpioReadPortDataP1x()		(EGPIO_P1_DATA)
#define	GpioReadPortDataP10()		(EGPIO_P1_DATA & EGPIO_P1_DATA_P10D)
#define	GpioReadPortDataP11()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P11D) >> 1)
#define	GpioReadPortDataP12()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P12D) >> 2)
#define	GpioReadPortDataP13()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P13D) >> 3)
#define	GpioReadPortDataP14()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P14D) >> 4)
#define	GpioReadPortDataP15()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P15D) >> 5)
#define	GpioReadPortDataP16()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P16D) >> 6)
#define	GpioReadPortDataP17()		((EGPIO_P1_DATA & EGPIO_P1_DATA_P17D) >> 7)

// P2x
#define	GpioReadPortDataP2x()		(EGPIO_P2_DATA)
#define	GpioReadPortDataP20()		(EGPIO_P2_DATA & EGPIO_P2_DATA_P20D)
#define	GpioReadPortDataP21()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P21D) >> 1)
#define	GpioReadPortDataP22()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P22D) >> 2)
#define	GpioReadPortDataP23()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P23D) >> 3)
#define	GpioReadPortDataP24()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P24D) >> 4)
#define	GpioReadPortDataP25()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P25D) >> 5)
#define	GpioReadPortDataP26()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P26D) >> 6)
#define	GpioReadPortDataP27()		((EGPIO_P2_DATA & EGPIO_P2_DATA_P27D) >> 7)

// P3x
#define	GpioReadPortDataP3x()		(EGPIO_P3_DATA)
#define	GpioReadPortDataP30()		(EGPIO_P3_DATA & EGPIO_P3_DATA_P30D)
#define	GpioReadPortDataP31()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P31D) >> 1)
#define	GpioReadPortDataP32()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P32D) >> 2)
#define	GpioReadPortDataP33()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P33D) >> 3)
#define	GpioReadPortDataP34()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P34D) >> 4)
#define	GpioReadPortDataP35()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P35D) >> 5)
#define	GpioReadPortDataP36()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P36D) >> 6)
#define	GpioReadPortDataP37()		((EGPIO_P3_DATA & EGPIO_P3_DATA_P37D) >> 7)

// P4x
#define	GpioReadPortDataP4x()		(EGPIO_P4_DATA)
#define	GpioReadPortDataP40()		(EGPIO_P4_DATA & EGPIO_P4_DATA_P40D)
#define	GpioReadPortDataP41()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P41D) >> 1)
#define	GpioReadPortDataP42()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P42D) >> 2)
#define	GpioReadPortDataP43()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P43D) >> 3)
#define	GpioReadPortDataP44()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P44D) >> 4)
#define	GpioReadPortDataP45()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P45D) >> 5)
#define	GpioReadPortDataP46()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P46D) >> 6)
#define	GpioReadPortDataP47()		((EGPIO_P4_DATA & EGPIO_P4_DATA_P47D) >> 7)

// P5x
#define	GpioReadPortDataP5x()		(EGPIO_P5_DATA)
#define	GpioReadPortDataP50()		(EGPIO_P5_DATA & EGPIO_P5_DATA_P50D)
#define	GpioReadPortDataP51()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P51D) >> 1)
#define	GpioReadPortDataP52()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P52D) >> 2)
#define	GpioReadPortDataP53()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P53D) >> 3)
#define	GpioReadPortDataP54()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P54D) >> 4)
#define	GpioReadPortDataP55()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P55D) >> 5)
#define	GpioReadPortDataP56()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P56D) >> 6)
#define	GpioReadPortDataP57()		((EGPIO_P5_DATA & EGPIO_P5_DATA_P57D) >> 7)

// P6x
#define	GpioReadPortDataP6x()		(EGPIO_P6_DATA)
#define	GpioReadPortDataP60()		(EGPIO_P6_DATA & EGPIO_P6_DATA_P60D)
#define	GpioReadPortDataP61()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P61D) >> 1)
#define	GpioReadPortDataP62()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P62D) >> 2)
#define	GpioReadPortDataP63()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P63D) >> 3)
#define	GpioReadPortDataP64()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P64D) >> 4)
#define	GpioReadPortDataP65()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P65D) >> 5)
#define	GpioReadPortDataP66()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P66D) >> 6)
#define	GpioReadPortDataP67()		((EGPIO_P6_DATA & EGPIO_P6_DATA_P67D) >> 7)

// P7x
#define	GpioReadPortDataP7x()		(EGPIO_P7_DATA)
#define	GpioReadPortDataP70()		(EGPIO_P7_DATA & EGPIO_P7_DATA_P70D)
#define	GpioReadPortDataP71()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P71D) >> 1)
#define	GpioReadPortDataP72()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P72D) >> 2)
#define	GpioReadPortDataP73()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P73D) >> 3)
#define	GpioReadPortDataP74()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P74D) >> 4)
#define	GpioReadPortDataP75()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P75D) >> 5)
#define	GpioReadPortDataP76()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P76D) >> 6)
#define	GpioReadPortDataP77()		((EGPIO_P7_DATA & EGPIO_P7_DATA_P77D) >> 7)

// P8x
#define	GpioReadPortDataP8x()		(EGPIO_P8_DATA)
#define	GpioReadPortDataP80()		(EGPIO_P8_DATA & EGPIO_P8_DATA_P80D)
#define	GpioReadPortDataP81()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P81D) >> 1)
#define	GpioReadPortDataP82()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P82D) >> 2)
#define	GpioReadPortDataP83()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P83D) >> 3)
#define	GpioReadPortDataP84()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P84D) >> 4)
#define	GpioReadPortDataP85()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P85D) >> 5)
#define	GpioReadPortDataP86()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P86D) >> 6)
#define	GpioReadPortDataP87()		((EGPIO_P8_DATA & EGPIO_P8_DATA_P87D) >> 7)

// P9x
#define	GpioReadPortDataP9x()		(EGPIO_P9_DATA)
#define	GpioReadPortDataP90()		(EGPIO_P9_DATA & EGPIO_P9_DATA_P90D)
#define	GpioReadPortDataP91()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P91D) >> 1)
#define	GpioReadPortDataP92()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P92D) >> 2)
#define	GpioReadPortDataP93()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P93D) >> 3)
#define	GpioReadPortDataP94()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P94D) >> 4)
#define	GpioReadPortDataP95()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P95D) >> 5)
#define	GpioReadPortDataP96()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P96D) >> 6)
#define	GpioReadPortDataP97()		((EGPIO_P9_DATA & EGPIO_P9_DATA_P97D) >> 7)

// PAx
#define	GpioReadPortDataPAx()		(EGPIO_PA_DATA)
#define	GpioReadPortDataPA0()		(EGPIO_PA_DATA & EGPIO_PA_DATA_PA0D)
#define	GpioReadPortDataPA1()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA1D) >> 1)
#define	GpioReadPortDataPA2()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA2D) >> 2)
#define	GpioReadPortDataPA3()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA3D) >> 3)
#define	GpioReadPortDataPA4()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA4D) >> 4)
#define	GpioReadPortDataPA5()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA5D) >> 5)
#define	GpioReadPortDataPA6()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA6D) >> 6)
#define	GpioReadPortDataPA7()		((EGPIO_PA_DATA & EGPIO_PA_DATA_PA7D) >> 7)

// PBx
#define	GpioReadPortDataPBx()		(EGPIO_PB_DATA)
#define	GpioReadPortDataPB0()		(EGPIO_PB_DATA & EGPIO_PB_DATA_PB0D)
#define	GpioReadPortDataPB1()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB1D) >> 1)
#define	GpioReadPortDataPB2()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB2D) >> 2)
#define	GpioReadPortDataPB3()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB3D) >> 3)
#define	GpioReadPortDataPB4()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB4D) >> 4)
#define	GpioReadPortDataPB5()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB5D) >> 5)
#define	GpioReadPortDataPB6()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB6D) >> 6)
#define	GpioReadPortDataPB7()		((EGPIO_PB_DATA & EGPIO_PB_DATA_PB7D) >> 7)

// PCx
#define	GpioReadPortDataPCx()		(EGPIO_PC_DATA)
#define	GpioReadPortDataPC0()		(EGPIO_PC_DATA & EGPIO_PC_DATA_PC0D)
#define	GpioReadPortDataPC1()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC1D) >> 1)
#define	GpioReadPortDataPC2()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC2D) >> 2)
#define	GpioReadPortDataPC3()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC3D) >> 3)
#define	GpioReadPortDataPC4()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC4D) >> 4)
#define	GpioReadPortDataPC5()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC5D) >> 5)
#define	GpioReadPortDataPC6()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC6D) >> 6)
#define	GpioReadPortDataPC7()		((EGPIO_PC_DATA & EGPIO_PC_DATA_PC7D) >> 7)


/* ----- Write data to port ----- */

// P0x
#define	GpioWritePortDataP0x(x)		EGPIO_P0_DATA	= x
#define	GpioSetPortDataP00()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P00D)
#define	GpioSetPortDataP01()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P01D)
#define	GpioSetPortDataP02()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P02D)
#define	GpioSetPortDataP03()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P03D)
#define	GpioSetPortDataP04()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P04D)
#define	GpioSetPortDataP05()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P05D)
#define	GpioSetPortDataP06()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P06D)
#define	GpioSetPortDataP07()		(EGPIO_P0_DATA	|= EGPIO_P0_DATA_P07D)
#define	GpioClrPortDataP00()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P00D))
#define	GpioClrPortDataP01()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P01D))
#define	GpioClrPortDataP02()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P02D))
#define	GpioClrPortDataP03()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P03D))
#define	GpioClrPortDataP04()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P04D))
#define	GpioClrPortDataP05()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P05D))
#define	GpioClrPortDataP06()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P06D))
#define	GpioClrPortDataP07()		(EGPIO_P0_DATA	&= ~(EGPIO_P0_DATA_P07D))

// P1x
#define	GpioWritePortDataP1x(x)		EGPIO_P1_DATA	= x
#define	GpioSetPortDataP10()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P10D)
#define	GpioSetPortDataP11()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P11D)
#define	GpioSetPortDataP12()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P12D)
#define	GpioSetPortDataP13()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P13D)
#define	GpioSetPortDataP14()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P14D)
#define	GpioSetPortDataP15()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P15D)
#define	GpioSetPortDataP16()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P16D)
#define	GpioSetPortDataP17()		(EGPIO_P1_DATA	|= EGPIO_P1_DATA_P17D)
#define	GpioClrPortDataP10()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P10D))
#define	GpioClrPortDataP11()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P11D))
#define	GpioClrPortDataP12()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P12D))
#define	GpioClrPortDataP13()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P13D))
#define	GpioClrPortDataP14()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P14D))
#define	GpioClrPortDataP15()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P15D))
#define	GpioClrPortDataP16()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P16D))
#define	GpioClrPortDataP17()		(EGPIO_P1_DATA	&= ~(EGPIO_P1_DATA_P17D))

// P2x
#define	GpioWritePortDataP2x(x)		EGPIO_P2_DATA	= x
#define	GpioSetPortDataP20()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P20D)
#define	GpioSetPortDataP21()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P21D)
#define	GpioSetPortDataP22()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P22D)
#define	GpioSetPortDataP23()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P23D)
#define	GpioSetPortDataP24()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P24D)
#define	GpioSetPortDataP25()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P25D)
#define	GpioSetPortDataP26()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P26D)
#define	GpioSetPortDataP27()		(EGPIO_P2_DATA	|= EGPIO_P2_DATA_P27D)
#define	GpioClrPortDataP20()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P20D))
#define	GpioClrPortDataP21()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P21D))
#define	GpioClrPortDataP22()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P22D))
#define	GpioClrPortDataP23()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P23D))
#define	GpioClrPortDataP24()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P24D))
#define	GpioClrPortDataP25()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P25D))
#define	GpioClrPortDataP26()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P26D))
#define	GpioClrPortDataP27()		(EGPIO_P2_DATA	&= ~(EGPIO_P2_DATA_P27D))

// P3x
#define	GpioWritePortDataP3x(x)		EGPIO_P3_DATA	= x
#define	GpioSetPortDataP30()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P30D)
#define	GpioSetPortDataP31()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P31D)
#define	GpioSetPortDataP32()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P32D)
#define	GpioSetPortDataP33()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P33D)
#define	GpioSetPortDataP34()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P34D)
#define	GpioSetPortDataP35()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P35D)
#define	GpioSetPortDataP36()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P36D)
#define	GpioSetPortDataP37()		(EGPIO_P3_DATA	|= EGPIO_P3_DATA_P37D)
#define	GpioClrPortDataP30()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P30D))
#define	GpioClrPortDataP31()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P31D))
#define	GpioClrPortDataP32()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P32D))
#define	GpioClrPortDataP33()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P33D))
#define	GpioClrPortDataP34()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P34D))
#define	GpioClrPortDataP35()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P35D))
#define	GpioClrPortDataP36()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P36D))
#define	GpioClrPortDataP37()		(EGPIO_P3_DATA	&= ~(EGPIO_P3_DATA_P37D))

// P4x
#define	GpioWritePortDataP4x(x)		EGPIO_P4_DATA	= x
#define	GpioSetPortDataP40()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P40D)
#define	GpioSetPortDataP41()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P41D)
#define	GpioSetPortDataP42()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P42D)
#define	GpioSetPortDataP43()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P43D)
#define	GpioSetPortDataP44()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P44D)
#define	GpioSetPortDataP45()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P45D)
#define	GpioSetPortDataP46()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P46D)
#define	GpioSetPortDataP47()		(EGPIO_P4_DATA	|= EGPIO_P4_DATA_P47D)
#define	GpioClrPortDataP40()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P40D))
#define	GpioClrPortDataP41()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P41D))
#define	GpioClrPortDataP42()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P42D))
#define	GpioClrPortDataP43()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P43D))
#define	GpioClrPortDataP44()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P44D))
#define	GpioClrPortDataP45()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P45D))
#define	GpioClrPortDataP46()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P46D))
#define	GpioClrPortDataP47()		(EGPIO_P4_DATA	&= ~(EGPIO_P4_DATA_P47D))

// P5x
#define	GpioWritePortDataP5x(x)		EGPIO_P5_DATA	= x
#define	GpioSetPortDataP50()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P50D)
#define	GpioSetPortDataP51()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P51D)
#define	GpioSetPortDataP52()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P52D)
#define	GpioSetPortDataP53()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P53D)
#define	GpioSetPortDataP54()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P54D)
#define	GpioSetPortDataP55()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P55D)
#define	GpioSetPortDataP56()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P56D)
#define	GpioSetPortDataP57()		(EGPIO_P5_DATA	|= EGPIO_P5_DATA_P57D)
#define	GpioClrPortDataP50()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P50D))
#define	GpioClrPortDataP51()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P51D))
#define	GpioClrPortDataP52()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P52D))
#define	GpioClrPortDataP53()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P53D))
#define	GpioClrPortDataP54()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P54D))
#define	GpioClrPortDataP55()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P55D))
#define	GpioClrPortDataP56()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P56D))
#define	GpioClrPortDataP57()		(EGPIO_P5_DATA	&= ~(EGPIO_P5_DATA_P57D))

// P6x
#define	GpioWritePortDataP6x(x)		EGPIO_P6_DATA	= x
#define	GpioSetPortDataP60()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P60D)
#define	GpioSetPortDataP61()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P61D)
#define	GpioSetPortDataP62()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P62D)
#define	GpioSetPortDataP63()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P63D)
#define	GpioSetPortDataP64()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P64D)
#define	GpioSetPortDataP65()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P65D)
#define	GpioSetPortDataP66()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P66D)
#define	GpioSetPortDataP67()		(EGPIO_P6_DATA	|= EGPIO_P6_DATA_P67D)
#define	GpioClrPortDataP60()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P60D))
#define	GpioClrPortDataP61()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P61D))
#define	GpioClrPortDataP62()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P62D))
#define	GpioClrPortDataP63()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P63D))
#define	GpioClrPortDataP64()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P64D))
#define	GpioClrPortDataP65()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P65D))
#define	GpioClrPortDataP66()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P66D))
#define	GpioClrPortDataP67()		(EGPIO_P6_DATA	&= ~(EGPIO_P6_DATA_P67D))

// P7x
#define	GpioWritePortDataP7x(x)		EGPIO_P7_DATA	= x
#define	GpioSetPortDataP70()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P70D)
#define	GpioSetPortDataP71()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P71D)
#define	GpioSetPortDataP72()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P72D)
#define	GpioSetPortDataP73()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P73D)
#define	GpioSetPortDataP74()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P74D)
#define	GpioSetPortDataP75()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P75D)
#define	GpioSetPortDataP76()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P76D)
#define	GpioSetPortDataP77()		(EGPIO_P7_DATA	|= EGPIO_P7_DATA_P77D)
#define	GpioClrPortDataP70()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P70D))
#define	GpioClrPortDataP71()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P71D))
#define	GpioClrPortDataP72()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P72D))
#define	GpioClrPortDataP73()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P73D))
#define	GpioClrPortDataP74()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P74D))
#define	GpioClrPortDataP75()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P75D))
#define	GpioClrPortDataP76()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P76D))
#define	GpioClrPortDataP77()		(EGPIO_P7_DATA	&= ~(EGPIO_P7_DATA_P77D))

// P8x
#define	GpioWritePortDataP8x(x)		EGPIO_P8_DATA	= x
#define	GpioSetPortDataP80()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P80D)
#define	GpioSetPortDataP81()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P81D)
#define	GpioSetPortDataP82()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P82D)
#define	GpioSetPortDataP83()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P83D)
#define	GpioSetPortDataP84()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P84D)
#define	GpioSetPortDataP85()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P85D)
#define	GpioSetPortDataP86()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P86D)
#define	GpioSetPortDataP87()		(EGPIO_P8_DATA	|= EGPIO_P8_DATA_P87D)
#define	GpioClrPortDataP80()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P80D))
#define	GpioClrPortDataP81()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P81D))
#define	GpioClrPortDataP82()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P82D))
#define	GpioClrPortDataP83()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P83D))
#define	GpioClrPortDataP84()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P84D))
#define	GpioClrPortDataP85()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P85D))
#define	GpioClrPortDataP86()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P86D))
#define	GpioClrPortDataP87()		(EGPIO_P8_DATA	&= ~(EGPIO_P8_DATA_P87D))

// P9x
#define	GpioWritePortDataP9x(x)		EGPIO_P9_DATA	= x
#define	GpioSetPortDataP90()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P90D)
#define	GpioSetPortDataP91()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P91D)
#define	GpioSetPortDataP92()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P92D)
#define	GpioSetPortDataP93()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P93D)
#define	GpioSetPortDataP94()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P94D)
#define	GpioSetPortDataP95()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P95D)
#define	GpioSetPortDataP96()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P96D)
#define	GpioSetPortDataP97()		(EGPIO_P9_DATA	|= EGPIO_P9_DATA_P97D)
#define	GpioClrPortDataP90()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P90D))
#define	GpioClrPortDataP91()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P91D))
#define	GpioClrPortDataP92()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P92D))
#define	GpioClrPortDataP93()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P93D))
#define	GpioClrPortDataP94()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P94D))
#define	GpioClrPortDataP95()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P95D))
#define	GpioClrPortDataP96()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P96D))
#define	GpioClrPortDataP97()		(EGPIO_P9_DATA	&= ~(EGPIO_P9_DATA_P97D))

// PAx
#define	GpioWritePortDataPAx(x)		EGPIO_PA_DATA	= x
#define	GpioSetPortDataPA0()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA0D)
#define	GpioSetPortDataPA1()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA1D)
#define	GpioSetPortDataPA2()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA2D)
#define	GpioSetPortDataPA3()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA3D)
#define	GpioSetPortDataPA4()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA4D)
#define	GpioSetPortDataPA5()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA5D)
#define	GpioSetPortDataPA6()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA6D)
#define	GpioSetPortDataPA7()		(EGPIO_PA_DATA	|= EGPIO_PA_DATA_PA7D)
#define	GpioClrPortDataPA0()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA0D))
#define	GpioClrPortDataPA1()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA1D))
#define	GpioClrPortDataPA2()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA2D))
#define	GpioClrPortDataPA3()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA3D))
#define	GpioClrPortDataPA4()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA4D))
#define	GpioClrPortDataPA5()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA5D))
#define	GpioClrPortDataPA6()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA6D))
#define	GpioClrPortDataPA7()		(EGPIO_PA_DATA	&= ~(EGPIO_PA_DATA_PA7D))

// PBx
#define	GpioWritePortDataPBx(x)		EGPIO_PB_DATA	= x
#define	GpioSetPortDataPB0()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB0D)
#define	GpioSetPortDataPB1()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB1D)
#define	GpioSetPortDataPB2()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB2D)
#define	GpioSetPortDataPB3()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB3D)
#define	GpioSetPortDataPB4()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB4D)
#define	GpioSetPortDataPB5()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB5D)
#define	GpioSetPortDataPB6()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB6D)
#define	GpioSetPortDataPB7()		(EGPIO_PB_DATA	|= EGPIO_PB_DATA_PB7D)
#define	GpioClrPortDataPB0()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB0D))
#define	GpioClrPortDataPB1()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB1D))
#define	GpioClrPortDataPB2()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB2D))
#define	GpioClrPortDataPB3()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB3D))
#define	GpioClrPortDataPB4()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB4D))
#define	GpioClrPortDataPB5()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB5D))
#define	GpioClrPortDataPB6()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB6D))
#define	GpioClrPortDataPB7()		(EGPIO_PB_DATA	&= ~(EGPIO_PB_DATA_PB7D))

// PCx
#define	GpioWritePortDataPCx(x)		EGPIO_PC_DATA	= x
#define	GpioSetPortDataPC0()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC0D)
#define	GpioSetPortDataPC1()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC1D)
#define	GpioSetPortDataPC2()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC2D)
#define	GpioSetPortDataPC3()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC3D)
#define	GpioSetPortDataPC4()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC4D)
#define	GpioSetPortDataPC5()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC5D)
#define	GpioSetPortDataPC6()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC6D)
#define	GpioSetPortDataPC7()		(EGPIO_PC_DATA	|= EGPIO_PC_DATA_PC7D)
#define	GpioClrPortDataPC0()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC0D))
#define	GpioClrPortDataPC1()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC1D))
#define	GpioClrPortDataPC2()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC2D))
#define	GpioClrPortDataPC3()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC3D))
#define	GpioClrPortDataPC4()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC4D))
#define	GpioClrPortDataPC5()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC5D))
#define	GpioClrPortDataPC6()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC6D))
#define	GpioClrPortDataPC7()		(EGPIO_PC_DATA	&= ~(EGPIO_PC_DATA_PC7D))


/* ----- Set I/O control ----- */

// P0x
#define	GpioSetPortIoCtrlP0x(x)		EGPIO_P0_IOC	= x
#define	GpioSetPortOutputP00()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC00)
#define	GpioSetPortOutputP01()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC01)
#define	GpioSetPortOutputP02()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC02)
#define	GpioSetPortOutputP03()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC03)
#define	GpioSetPortOutputP04()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC04)
#define	GpioSetPortOutputP05()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC05)
#define	GpioSetPortOutputP06()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC06)
#define	GpioSetPortOutputP07()		(EGPIO_P0_IOC	|= EGPIO_P0_IOC_IOC07)
#define	GpioSetPortInputP00()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC00))
#define	GpioSetPortInputP01()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC01))
#define	GpioSetPortInputP02()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC02))
#define	GpioSetPortInputP03()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC03))
#define	GpioSetPortInputP04()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC04))
#define	GpioSetPortInputP05()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC05))
#define	GpioSetPortInputP06()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC06))
#define	GpioSetPortInputP07()		(EGPIO_P0_IOC	&= ~(EGPIO_P0_IOC_IOC07))

// P1x
#define	GpioSetPortIoCtrlP1x(x)		EGPIO_P1_IOC	= x
#define	GpioSetPortOutputP10()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC10)
#define	GpioSetPortOutputP11()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC11)
#define	GpioSetPortOutputP12()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC12)
#define	GpioSetPortOutputP13()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC13)
#define	GpioSetPortOutputP14()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC14)
#define	GpioSetPortOutputP15()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC15)
#define	GpioSetPortOutputP16()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC16)
#define	GpioSetPortOutputP17()		(EGPIO_P1_IOC	|= EGPIO_P1_IOC_IOC17)
#define	GpioSetPortInputP10()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC10))
#define	GpioSetPortInputP11()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC11))
#define	GpioSetPortInputP12()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC12))
#define	GpioSetPortInputP13()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC13))
#define	GpioSetPortInputP14()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC14))
#define	GpioSetPortInputP15()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC15))
#define	GpioSetPortInputP16()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC16))
#define	GpioSetPortInputP17()		(EGPIO_P1_IOC	&= ~(EGPIO_P1_IOC_IOC17))

// P2x
#define	GpioSetPortIoCtrlP2x(x)		EGPIO_P2_IOC	= x
#define	GpioSetPortOutputP20()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC20)
#define	GpioSetPortOutputP21()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC21)
#define	GpioSetPortOutputP22()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC22)
#define	GpioSetPortOutputP23()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC23)
#define	GpioSetPortOutputP24()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC24)
#define	GpioSetPortOutputP25()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC25)
#define	GpioSetPortOutputP26()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC26)
#define	GpioSetPortOutputP27()		(EGPIO_P2_IOC	|= EGPIO_P2_IOC_IOC27)
#define	GpioSetPortInputP20()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC20))
#define	GpioSetPortInputP21()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC21))
#define	GpioSetPortInputP22()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC22))
#define	GpioSetPortInputP23()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC23))
#define	GpioSetPortInputP24()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC24))
#define	GpioSetPortInputP25()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC25))
#define	GpioSetPortInputP26()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC26))
#define	GpioSetPortInputP27()		(EGPIO_P2_IOC	&= ~(EGPIO_P2_IOC_IOC27))

// P3x
#define	GpioSetPortIoCtrlP3x(x)		EGPIO_P3_IOC	= x
#define	GpioSetPortOutputP30()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC30)
#define	GpioSetPortOutputP31()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC31)
#define	GpioSetPortOutputP32()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC32)
#define	GpioSetPortOutputP33()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC33)
#define	GpioSetPortOutputP34()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC34)
#define	GpioSetPortOutputP35()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC35)
#define	GpioSetPortOutputP36()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC36)
#define	GpioSetPortOutputP37()		(EGPIO_P3_IOC	|= EGPIO_P3_IOC_IOC37)
#define	GpioSetPortInputP30()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC30))
#define	GpioSetPortInputP31()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC31))
#define	GpioSetPortInputP32()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC32))
#define	GpioSetPortInputP33()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC33))
#define	GpioSetPortInputP34()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC34))
#define	GpioSetPortInputP35()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC35))
#define	GpioSetPortInputP36()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC36))
#define	GpioSetPortInputP37()		(EGPIO_P3_IOC	&= ~(EGPIO_P3_IOC_IOC37))

// P4x
#define	GpioSetPortIoCtrlP4x(x)		EGPIO_P4_IOC	= x
#define	GpioSetPortOutputP40()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC40)
#define	GpioSetPortOutputP41()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC41)
#define	GpioSetPortOutputP42()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC42)
#define	GpioSetPortOutputP43()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC43)
#define	GpioSetPortOutputP44()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC44)
#define	GpioSetPortOutputP45()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC45)
#define	GpioSetPortOutputP46()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC46)
#define	GpioSetPortOutputP47()		(EGPIO_P4_IOC	|= EGPIO_P4_IOC_IOC47)
#define	GpioSetPortInputP40()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC40))
#define	GpioSetPortInputP41()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC41))
#define	GpioSetPortInputP42()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC42))
#define	GpioSetPortInputP43()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC43))
#define	GpioSetPortInputP44()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC44))
#define	GpioSetPortInputP45()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC45))
#define	GpioSetPortInputP46()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC46))
#define	GpioSetPortInputP47()		(EGPIO_P4_IOC	&= ~(EGPIO_P4_IOC_IOC47))

// P5x
#define	GpioSetPortIoCtrlP5x(x)		EGPIO_P5_IOC	= x
#define	GpioSetPortOutputP50()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC50)
#define	GpioSetPortOutputP51()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC51)
#define	GpioSetPortOutputP52()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC52)
#define	GpioSetPortOutputP53()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC53)
#define	GpioSetPortOutputP54()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC54)
#define	GpioSetPortOutputP55()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC55)
#define	GpioSetPortOutputP56()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC56)
#define	GpioSetPortOutputP57()		(EGPIO_P5_IOC	|= EGPIO_P5_IOC_IOC57)
#define	GpioSetPortInputP50()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC50))
#define	GpioSetPortInputP51()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC51))
#define	GpioSetPortInputP52()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC52))
#define	GpioSetPortInputP53()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC53))
#define	GpioSetPortInputP54()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC54))
#define	GpioSetPortInputP55()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC55))
#define	GpioSetPortInputP56()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC56))
#define	GpioSetPortInputP57()		(EGPIO_P5_IOC	&= ~(EGPIO_P5_IOC_IOC57))

// P6x
#define	GpioSetPortIoCtrlP6x(x)		EGPIO_P6_IOC	= x
#define	GpioSetPortOutputP60()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC60)
#define	GpioSetPortOutputP61()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC61)
#define	GpioSetPortOutputP62()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC62)
#define	GpioSetPortOutputP63()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC63)
#define	GpioSetPortOutputP64()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC64)
#define	GpioSetPortOutputP65()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC65)
#define	GpioSetPortOutputP66()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC66)
#define	GpioSetPortOutputP67()		(EGPIO_P6_IOC	|= EGPIO_P6_IOC_IOC67)
#define	GpioSetPortInputP60()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC60))
#define	GpioSetPortInputP61()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC61))
#define	GpioSetPortInputP62()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC62))
#define	GpioSetPortInputP63()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC63))
#define	GpioSetPortInputP64()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC64))
#define	GpioSetPortInputP65()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC65))
#define	GpioSetPortInputP66()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC66))
#define	GpioSetPortInputP67()		(EGPIO_P6_IOC	&= ~(EGPIO_P6_IOC_IOC67))

// P7x
#define	GpioSetPortIoCtrlP7x(x)		EGPIO_P7_IOC	= x
#define	GpioSetPortOutputP70()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC70)
#define	GpioSetPortOutputP71()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC71)
#define	GpioSetPortOutputP72()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC72)
#define	GpioSetPortOutputP73()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC73)
#define	GpioSetPortOutputP74()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC74)
#define	GpioSetPortOutputP75()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC75)
#define	GpioSetPortOutputP76()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC76)
#define	GpioSetPortOutputP77()		(EGPIO_P7_IOC	|= EGPIO_P7_IOC_IOC77)
#define	GpioSetPortInputP70()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC70))
#define	GpioSetPortInputP71()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC71))
#define	GpioSetPortInputP72()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC72))
#define	GpioSetPortInputP73()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC73))
#define	GpioSetPortInputP74()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC74))
#define	GpioSetPortInputP75()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC75))
#define	GpioSetPortInputP76()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC76))
#define	GpioSetPortInputP77()		(EGPIO_P7_IOC	&= ~(EGPIO_P7_IOC_IOC77))

// P8x
#define	GpioSetPortIoCtrlP8x(x)		EGPIO_P8_IOC	= x
#define	GpioSetPortOutputP80()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC80)
#define	GpioSetPortOutputP81()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC81)
#define	GpioSetPortOutputP82()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC82)
#define	GpioSetPortOutputP83()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC83)
#define	GpioSetPortOutputP84()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC84)
#define	GpioSetPortOutputP85()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC85)
#define	GpioSetPortOutputP86()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC86)
#define	GpioSetPortOutputP87()		(EGPIO_P8_IOC	|= EGPIO_P8_IOC_IOC87)
#define	GpioSetPortInputP80()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC80))
#define	GpioSetPortInputP81()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC81))
#define	GpioSetPortInputP82()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC82))
#define	GpioSetPortInputP83()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC83))
#define	GpioSetPortInputP84()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC84))
#define	GpioSetPortInputP85()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC85))
#define	GpioSetPortInputP86()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC86))
#define	GpioSetPortInputP87()		(EGPIO_P8_IOC	&= ~(EGPIO_P8_IOC_IOC87))

// P9x
#define	GpioSetPortIoCtrlP9x(x)		EGPIO_P9_IOC	= x
#define	GpioSetPortOutputP90()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC90)
#define	GpioSetPortOutputP91()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC91)
#define	GpioSetPortOutputP92()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC92)
#define	GpioSetPortOutputP93()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC93)
#define	GpioSetPortOutputP94()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC94)
#define	GpioSetPortOutputP95()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC95)
#define	GpioSetPortOutputP96()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC96)
#define	GpioSetPortOutputP97()		(EGPIO_P9_IOC	|= EGPIO_P9_IOC_IOC97)
#define	GpioSetPortInputP90()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC90))
#define	GpioSetPortInputP91()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC91))
#define	GpioSetPortInputP92()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC92))
#define	GpioSetPortInputP93()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC93))
#define	GpioSetPortInputP94()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC94))
#define	GpioSetPortInputP95()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC95))
#define	GpioSetPortInputP96()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC96))
#define	GpioSetPortInputP97()		(EGPIO_P9_IOC	&= ~(EGPIO_P9_IOC_IOC97))

// PAx
#define	GpioSetPortIoCtrlPAx(x)		EGPIO_PA_IOC	= x
#define	GpioSetPortOutputPA0()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA0)
#define	GpioSetPortOutputPA1()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA1)
#define	GpioSetPortOutputPA2()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA2)
#define	GpioSetPortOutputPA3()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA3)
#define	GpioSetPortOutputPA4()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA4)
#define	GpioSetPortOutputPA5()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA5)
#define	GpioSetPortOutputPA6()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA6)
#define	GpioSetPortOutputPA7()		(EGPIO_PA_IOC	|= EGPIO_PA_IOC_IOCA7)
#define	GpioSetPortInputPA0()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA0))
#define	GpioSetPortInputPA1()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA1))
#define	GpioSetPortInputPA2()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA2))
#define	GpioSetPortInputPA3()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA3))
#define	GpioSetPortInputPA4()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA4))
#define	GpioSetPortInputPA5()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA5))
#define	GpioSetPortInputPA6()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA6))
#define	GpioSetPortInputPA7()		(EGPIO_PA_IOC	&= ~(EGPIO_PA_IOC_IOCA7))

// PBx
#define	GpioSetPortIoCtrlPBx(x)		EGPIO_PB_IOC	= x
#define	GpioSetPortOutputPB0()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB0)
#define	GpioSetPortOutputPB1()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB1)
#define	GpioSetPortOutputPB2()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB2)
#define	GpioSetPortOutputPB3()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB3)
#define	GpioSetPortOutputPB4()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB4)
#define	GpioSetPortOutputPB5()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB5)
#define	GpioSetPortOutputPB6()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB6)
#define	GpioSetPortOutputPB7()		(EGPIO_PB_IOC	|= EGPIO_PB_IOC_IOCB7)
#define	GpioSetPortInputPB0()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB0))
#define	GpioSetPortInputPB1()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB1))
#define	GpioSetPortInputPB2()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB2))
#define	GpioSetPortInputPB3()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB3))
#define	GpioSetPortInputPB4()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB4))
#define	GpioSetPortInputPB5()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB5))
#define	GpioSetPortInputPB6()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB6))
#define	GpioSetPortInputPB7()		(EGPIO_PB_IOC	&= ~(EGPIO_PB_IOC_IOCB7))

// PCx
#define	GpioSetPortIoCtrlPCx(x)		EGPIO_PC_IOC	= x
#define	GpioSetPortOutputPC0()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC0)
#define	GpioSetPortOutputPC1()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC1)
#define	GpioSetPortOutputPC2()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC2)
#define	GpioSetPortOutputPC3()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC3)
#define	GpioSetPortOutputPC4()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC4)
#define	GpioSetPortOutputPC5()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC5)
#define	GpioSetPortOutputPC6()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC6)
#define	GpioSetPortOutputPC7()		(EGPIO_PC_IOC	|= EGPIO_PC_IOC_IOCC7)
#define	GpioSetPortInputPC0()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC0))
#define	GpioSetPortInputPC1()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC1))
#define	GpioSetPortInputPC2()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC2))
#define	GpioSetPortInputPC3()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC3))
#define	GpioSetPortInputPC4()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC4))
#define	GpioSetPortInputPC5()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC5))
#define	GpioSetPortInputPC6()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC6))
#define	GpioSetPortInputPC7()		(EGPIO_PC_IOC	&= ~(EGPIO_PC_IOC_IOCC7))


/* ----- Set port function ----- */

// P0x
#define	GpioSetPortFuncP0_03(x)		EGPIO_P0_03_CFP	= x
#define	GpioSetPortFuncP0_47(x)		EGPIO_P0_47_CFP	= x

// P1x
#define	GpioSetPortFuncP1_03(x)		EGPIO_P1_03_CFP	= x
#define	GpioSetPortFuncP1_47(x)		EGPIO_P1_46_CFP	= x

// P2x
#define	GpioSetPortFuncP2_03(x)		EGPIO_P2_03_CFP	= x
#define	GpioSetPortFuncP2_47(x)		EGPIO_P2_47_CFP	= x

// P3x
#define	GpioSetPortFuncP3_03(x)		EGPIO_P3_03_CFP	= x
#define	GpioSetPortFuncP3_47(x)		EGPIO_P3_47_CFP	= x

// P4x
#define	GpioSetPortFuncP4_03(x)		EGPIO_P4_03_CFP	= x
#define	GpioSetPortFuncP4_47(x)		EGPIO_P4_45_CFP	= x

// P5x
#define	GpioSetPortFuncP5_03(x)		EGPIO_P5_03_CFP	= x
#define	GpioSetPortFuncP5_47(x)		EGPIO_P5_47_CFP	= x

// P6x
#define	GpioSetPortFuncP6_03(x)		EGPIO_P6_03_CFP	= x
#define	GpioSetPortFuncP6_47(x)		EGPIO_P6_47_CFP	= x

// P7x
#define	GpioSetPortFuncP7_03(x)		EGPIO_P7_03_CFP	= x
#define	GpioSetPortFuncP7_47(x)		EGPIO_P7_47_CFP	= x

// P8x
#define	GpioSetPortFuncP8_03(x)		EGPIO_P8_03_CFP	= x
#define	GpioSetPortFuncP8_47(x)		EGPIO_P8_46_CFP	= x

// P9x
#define	GpioSetPortFuncP9_03(x)		EGPIO_P9_03_CFP	= x
#define	GpioSetPortFuncP9_47(x)		EGPIO_P9_47_CFP	= x

// PAx
#define	GpioSetPortFuncPA_03(x)		EGPIO_PA_03_CFP	= x
#define	GpioSetPortFuncPA_47(x)		EGPIO_PA_46_CFP	= x

// PBx
#define	GpioSetPortFuncPB_03(x)		EGPIO_PB_03_CFP	= x
#define	GpioSetPortFuncPB_47(x)		EGPIO_PB_47_CFP	= x

// PCx
#define	GpioSetPortFuncPC_03(x)		EGPIO_PC_03_CFP	= x
#define	GpioSetPortFuncPC_47(x)		EGPIO_PC_47_CFP	= x


/* ----- Get port function ----- */

// P0x
#define	GpioGetPortFuncP0_03()		(EGPIO_P0_03_CFP)
#define	GpioGetPortFuncP0_47()		(EGPIO_P0_47_CFP)

// P1x
#define	GpioGetPortFuncP1_03()		(EGPIO_P1_03_CFP)
#define	GpioGetPortFuncP1_47()		(EGPIO_P1_46_CFP)

// P2x
#define	GpioGetPortFuncP2_03()		(EGPIO_P2_03_CFP)
#define	GpioGetPortFuncP2_47()		(EGPIO_P2_47_CFP)

// P3x
#define	GpioGetPortFuncP3_03()		(EGPIO_P3_03_CFP)
#define	GpioGetPortFuncP3_47()		(EGPIO_P3_47_CFP)

// P4x
#define	GpioGetPortFuncP4_03()		(EGPIO_P4_03_CFP)
#define	GpioGetPortFuncP4_47()		(EGPIO_P4_45_CFP)

// P5x
#define	GpioGetPortFuncP5_03()		(EGPIO_P5_03_CFP)
#define	GpioGetPortFuncP5_47()		(EGPIO_P5_47_CFP)

// P6x
#define	GpioGetPortFuncP6_03()		(EGPIO_P6_03_CFP)
#define	GpioGetPortFuncP6_47()		(EGPIO_P6_47_CFP)

// P7x
#define	GpioGetPortFuncP7_03()		(EGPIO_P7_03_CFP)
#define	GpioGetPortFuncP7_47()		(EGPIO_P7_47_CFP)

// P8x
#define	GpioGetPortFuncP8_03()		(EGPIO_P8_03_CFP)
#define	GpioGetPortFuncP8_47()		(EGPIO_P8_46_CFP)

// P9x
#define	GpioGetPortFuncP9_03()		(EGPIO_P9_03_CFP)
#define	GpioGetPortFuncP9_47()		(EGPIO_P9_47_CFP)

// PAx
#define	GpioGetPortFuncPA_03()		(EGPIO_PA_03_CFP)
#define	GpioGetPortFuncPA_47()		(EGPIO_PA_46_CFP)

// PBx
#define	GpioGetPortFuncPB_03()		(EGPIO_PB_03_CFP)
#define	GpioGetPortFuncPB_47()		(EGPIO_PB_47_CFP)

// PCx
#define	GpioGetPortFuncPC_03()		(EGPIO_PC_03_CFP)
#define	GpioGetPortFuncPC_47()		(EGPIO_PC_47_CFP)


/* ----- Select port interrupt ----- */

#define	GpioSelectPortInt0(x)		EGPIO_PINTSEL_SPT0	= x
#define	GpioSelectPortInt1(x)		EGPIO_PINTSEL_SPT1	= x
#define	GpioSelectPortInt2(x)		EGPIO_PINTSEL_SPT2	= x
#define	GpioSelectPortInt3(x)		EGPIO_PINTSEL_SPT3	= x
#define	GpioSelectPortInt4(x)		EGPIO_PINTSEL_SPT4	= x
#define	GpioSelectPortInt5(x)		EGPIO_PINTSEL_SPT5	= x
#define	GpioSelectPortInt6(x)		EGPIO_PINTSEL_SPT6	= x
#define	GpioSelectPortInt7(x)		EGPIO_PINTSEL_SPT7	= x


// Macro APIs
#define	GpioReadPortData(x,y)		GpioReadPortDataP##x##y()
#define	GpioWritePortData(y,z)	GpioWritePortDataP##y##x(z)

#define	GpioClrPortData(x,y)		GpioClrPortDataP##x##y()
#define	GpioSetPortData(x,y)		GpioSetPortDataP##x##y()

#define	GpioSetPortIoCtrl(y,z)		GpioSetPortIoCtrlP##y##x(z)

#define	GpioSetPortInput(x,y)		GpioSetPortInputP##x##y()
#define	GpioSetPortOutput(x,y)		GpioSetPortOutputP##x##y()
#define	GpioSetPortFunc(x,y)		GpioSetPortFuncP##x##_03((y)->uc.CFP03);\
									GpioSetPortFuncP##x##_47((y)->uc.CFP47)
#define	GpioGetPortFunc(x)			(GpioGetPortFuncP##x##_03() | (GpioGetPortFuncP##x##_47() << 8))
#define	GpioSelectPortInt(x,y)		GpioSelectPortInt##x(y)


#ifdef	__cplusplus
extern "C" {
#endif

// APIs
#ifdef	FOR_GPIO_USE_INTR
extern void GpioIntInit(T_GPIO_CFG *);
#endif

extern void GpioIntHdlr0(void);
extern void GpioIntHdlr1(void);
extern void GpioIntHdlr2(void);
extern void GpioIntHdlr3(void);
extern void GpioIntHdlr4(void);
extern void GpioIntHdlr5(void);
extern void GpioIntHdlr6(void);
extern void GpioIntHdlr7(void);


#ifdef __cplusplus
}
#endif

#endif	// __GPIO_API_H__

