/***************************************************************************
*
*	File name : main.c
*	Function  : Main function
*	Revision  :
*		07/31/2007	Nariai		First revision
*
****************************************************************************/

// Include File
#include	<stdio.h>
#include	<stdlib.h>
#include	<string.h>
#include	<ctype.h>
#include	"reg_801.h"
#include	"system.h"
#include	"itc_api.h"
#include	"gpio_api.h"
#include	"remc_api.h"

// Define

// Prototype
int main(void);
static void RemcInitialize(unsigned short);
static void PortInitialize(void);
static void ItcInitialize(void);
static void InterruptMaskREMC(unsigned char);

// Global
unsigned char remBuffer[5];

unsigned char	inbuff[128];
unsigned char	outbuff[128];

/***************************************************************************
	main

	description	: main function
	argument	:
	return: 	:

	input		:
	output		:

	flag		:
	global		:
***************************************************************************/
int main(void){

	long			i;

	PortInitialize();
	ItcInitialize();

	// CPU interrupt enable
	CpuIntEnable();


	sprintf(outbuff,"This is sample program for REMC.\n");
	printf(outbuff);
	sprintf(outbuff,"Transmit or Receive for NEC format.\n");
	printf(outbuff);


	while(1){

		sprintf(outbuff,"command > ");
		printf(outbuff);
		scanf("%s",inbuff);

		if(strcmp(inbuff,"help") == 0 || strcmp(inbuff,"?") == 0){

			sprintf(outbuff,"tran : transmit.\n");
			printf(outbuff);
			sprintf(outbuff,"recv : receive.\n");
			printf(outbuff);

		} else if(strcmp(inbuff,"tran") == 0){

			while(1){

				RemcInitialize(REMC_TRANSMIT);

				sprintf(outbuff,"tran command > ");
				printf(outbuff);
				scanf("%s",inbuff);

				if(strcmp(inbuff,"help") == 0 || strcmp(inbuff,"?") == 0){
					sprintf(outbuff,"pow    : Power Button.\n");
					printf(outbuff);
					sprintf(outbuff,"mute   : Mute Button.\n");
					printf(outbuff);
					sprintf(outbuff,"1 - 12 : 1 - 12 Button.\n");
					printf(outbuff);
					sprintf(outbuff,"up     : Volume Up Button.\n");
					printf(outbuff);
					sprintf(outbuff,"down   : Volume Down Button.\n");
					printf(outbuff);
					sprintf(outbuff,"exit   : exit transmit.\n");
					printf(outbuff);

					continue;

				} else if(strcmp(inbuff,"pow") == 0){
					remBuffer[2] = 0x08;
				} else if(strcmp(inbuff,"mute") == 0){
					remBuffer[2] = 0x09;
				} else if(strcmp(inbuff,"up") == 0){
					remBuffer[2] = 0x02;
				} else if(strcmp(inbuff,"down") == 0){
					remBuffer[2] = 0x03;
				} else if(strcmp(inbuff,"1") == 0){
					remBuffer[2] = 0x10;
				} else if(strcmp(inbuff,"2") == 0){
					remBuffer[2] = 0x11;
				} else if(strcmp(inbuff,"3") == 0){
					remBuffer[2] = 0x12;
				} else if(strcmp(inbuff,"4") == 0){
					remBuffer[2] = 0x13;
				} else if(strcmp(inbuff,"5") == 0){
					remBuffer[2] = 0x14;
				} else if(strcmp(inbuff,"6") == 0){
					remBuffer[2] = 0x15;
				} else if(strcmp(inbuff,"7") == 0){
					remBuffer[2] = 0x16;
				} else if(strcmp(inbuff,"8") == 0){
					remBuffer[2] = 0x17;
				} else if(strcmp(inbuff,"9") == 0){
					remBuffer[2] = 0x18;
				} else if(strcmp(inbuff,"10") == 0){
					remBuffer[2] = 0x19;
				} else if(strcmp(inbuff,"11") == 0){
					remBuffer[2] = 0x1a;
				} else if(strcmp(inbuff,"12") == 0){
					remBuffer[2] = 0x1b;
				} else if(strcmp(inbuff,"exit") == 0){
					break;
				} else {
					continue;
				}

				remBuffer[3] = ~remBuffer[2];

				while(RemcTransmit(remBuffer) != SUCCESS);

				sprintf(outbuff,"Tran : Maker code %02X Key code %02X\n", remBuffer[0], remBuffer[2]);
				printf(outbuff);
			}

		} else if(strcmp(inbuff,"recv") == 0){

			sprintf(outbuff,"Exit receive mode by Power SW button.\n");
			printf(outbuff);

			RemcInitialize(REMC_RECEIVE);

			while(1){

				if(RemcReceive(remBuffer) == SUCCESS){
					if(remBuffer[0] == 0x18 && remBuffer[1] == 0xe7 && remBuffer[2] == (~remBuffer[3] & 0xFF)){
						sprintf(outbuff,"Recv : Normal custom code %02X%02X Key code %02X\n", remBuffer[0], remBuffer[1], remBuffer[2]);
						printf(outbuff);

						if(remBuffer[2] == 0x08){
							break;
						}
					} else {
						sprintf(outbuff,"Recv : Illegal custom code %02X%02X Key code %02X\n", remBuffer[0], remBuffer[1], remBuffer[2]);
						printf(outbuff);
					}
				}
			}
		}
	}

	return 0;

}

/***************************************************************************
	RemcInitialize

	description	: Initialize for REMC
	argument	:
		mode	: Transfer mode
	return: 	: None

***************************************************************************/
static void RemcInitialize(unsigned short mode){

	T_REMC_CFG		Config;

	Config.mode			= mode;
	Config.systemClock	= 48000000;
	Config.divide		= REMC_PSDIV_24;
	Config.carrierHigh	= 17;
	Config.carrierLow	= 34;
	Config.dataCodeBit	= 32;
	Config.T_ON			= 560;
	Config.T_OFF		= 560;
	Config.averageError	= 200;
	Config.leaderON		= 16;
	Config.leaderOFF	= 8;
	Config.data0ON		= 1;
	Config.data0OFF		= 1;
	Config.data1ON		= 1;
	Config.data1OFF		= 3;
	Config.stopON		= 1;
	Config.stopOFF		= 54;

	Config.intMaskFunc	= InterruptMaskREMC;

	if(mode == REMC_TRANSMIT){

		remBuffer[0] = 0x18;
		remBuffer[1] = 0xe7;
		remBuffer[2] = 0;
		remBuffer[3] = ~remBuffer[2];

	} else {
		remBuffer[0] = 0;
		remBuffer[1] = 0;
		remBuffer[2] = 0;
		remBuffer[3] = 0;
	}

	RemcInit(&Config);
}

/***************************************************************************
	PortInitialize

	description	: Init. Port
	argument	: None
	return: 	: None

	input		:
	output		:

	flag		: None
	global		: None
***************************************************************************/
static void PortInitialize(void){

	U_GPIO_FUNC_SEL	portFunc;

	// Setting port for Rem-OUT/IN
	portFunc.CFP		= GpioGetPortFunc(5);
	portFunc.b.CFPx2	= GPIO_FUNCTION_1;
	portFunc.b.CFPx3	= GPIO_FUNCTION_1;
	GpioSetPortFunc(5, &portFunc);
}

/***************************************************************************
	ItcInitialize

	description	: Init. ITC
	argument	: None
	return: 	: None

	input		:
	output		:

	flag		: None
	global		: None
***************************************************************************/
static void ItcInitialize(void){

	T_ITC_CFG	itcConfig;

	itcConfig.addIntEn.bit.mft			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.adcRange		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.adcEnd		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.rtc			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch0		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch1		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch2		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.t8Ch3		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.lcdc			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.espi			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.usb			= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.i2sTran		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.i2sRcv		= ITC_INT_DISABLE;
	itcConfig.addIntEn.bit.remc			= ITC_INT_ENABLE;

	itcConfig.addIntLv0.bit.mft			= 0;
	itcConfig.addIntLv1.bit.adcRange	= 0;
	itcConfig.addIntLv1.bit.adcEnd		= 0;
	itcConfig.addIntLv2.bit.rtc			= 0;
	itcConfig.addIntLv2.bit.t8Ch0		= 0;
	itcConfig.addIntLv3.bit.t8Ch1		= 0;
	itcConfig.addIntLv3.bit.t8Ch2		= 0;
	itcConfig.addIntLv4.bit.t8Ch3		= 0;
	itcConfig.addIntLv4.bit.lcdc		= 0;
	itcConfig.addIntLv5.bit.espi		= 0;
	itcConfig.addIntLv5.bit.usb			= 0;
	itcConfig.addIntLv6.bit.i2sTran		= 0;
	itcConfig.addIntLv6.bit.i2sRcv		= 0;
	itcConfig.addIntLv7.bit.remc		= 7;

	itcConfig.intEn.bit.port0			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port1			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port2			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port3			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port4			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port5			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port6			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.port7			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.clgT16U			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.clgT8S			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.clgT8I			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.uart			= ITC_INT_DISABLE;
	itcConfig.intEn.bit.spi				= ITC_INT_DISABLE;
	itcConfig.intEn.bit.i2c				= ITC_INT_DISABLE;

	itcConfig.extIntLv0.bit.port0		= 3;
	itcConfig.extIntLv0.bit.port0_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv0.bit.port0_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv0.bit.port1		= 3;
	itcConfig.extIntLv0.bit.port1_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv0.bit.port1_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv1.bit.port2		= 3;
	itcConfig.extIntLv1.bit.port2_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv1.bit.port2_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv1.bit.port3		= 3;
	itcConfig.extIntLv1.bit.port3_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv1.bit.port3_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv2.bit.port4		= 3;
	itcConfig.extIntLv2.bit.port4_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv2.bit.port4_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv2.bit.port5		= 3;
	itcConfig.extIntLv2.bit.port5_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv2.bit.port5_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv3.bit.port6		= 3;
	itcConfig.extIntLv3.bit.port6_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv3.bit.port6_TP	= ITC_TP_POSITIVE;
	itcConfig.extIntLv3.bit.port7		= 3;
	itcConfig.extIntLv3.bit.port7_TM	= ITC_TM_LEVEL;
	itcConfig.extIntLv3.bit.port7_TP	= ITC_TP_POSITIVE;

	itcConfig.inIntLv0.bit.clgT16U		= 3;
	itcConfig.inIntLv1.bit.clgT8S		= 3;
	itcConfig.inIntLv1.bit.clgT8I		= 3;
	itcConfig.inIntLv2.bit.uart			= 3;
	itcConfig.inIntLv3.bit.spi			= 3;
	itcConfig.inIntLv3.bit.i2c			= 3;

	itcConfig.funcEnable				= ITC_FUNC_ENABLE;

	ItcInit(&itcConfig);

	return;

}

/***************************************************************************
	InterruptMaskREMC

	description	: Interrupt Mask for REMC
	argument	:
		mask	: REMC_INT_ENABLE
				: REMC_INT_DISABLE
	return: 	:

***************************************************************************/
static void InterruptMaskREMC(unsigned char mask){

	if(mask == REMC_INT_ENABLE){
		ItcRemcIntEnable();				// enable REMC int.
	}

	if(mask == REMC_INT_DISABLE){
		ItcRemcIntDisable();				// disable REMC int.
	}
}
