/***************************************************************************
*
*	File name : remc_api.h
*	Function  : remc driver (C17801)
*	Revision  :
*		July. 30, 2007	Yakushiji		First revision
*
****************************************************************************/

#ifndef	___REMC_API_H___
#define	___REMC_API_H___

typedef struct {
	unsigned short		mode;			// Transmit/Receive mode
	unsigned long		systemClock;	// System clock
	unsigned short		divide;			// Prescaler divide ratio
	unsigned short		carrierHigh;	// Carrier High
	unsigned short		carrierLow;		// Carrier Low

	// Infrared-Red Remote Controller format
	unsigned short		dataCodeBit;	// Bit count of Data code

	unsigned short		T_ON;			// T ON pulse wide (us)
	unsigned short		T_OFF;			// T OFF pulse wide(us)
	unsigned short		averageError;	// average error(us)
	unsigned short		leaderON;		// Leader Code ON  (T_ON count)
	unsigned short		leaderOFF;		// Leader Code OFF (T_OFF count)
	unsigned short		data0ON;		// Bit data 0 ON   (T_ON count)
	unsigned short		data0OFF;		// Bit data 0 OFF  (T_OFF count)
	unsigned short		data1ON;		// Bit data 1 ON   (T_ON count)
	unsigned short		data1OFF;		// Bit data 1 OFF  (T_OFF count)
	unsigned short		stopON;			// Stop Code ON    (T_ON count)
	unsigned short		stopOFF;		// Stop Code OFF   (T_OFF count)
	void				(*intMaskFunc)(unsigned char);
										// Interrupt mask function

} T_REMC_CFG;

// Mode
#define	REMC_TRANSMIT	0x0000			// mode for transmit
#define	REMC_RECEIVE	0x0080			// mode for receive

// Prescaler value
#define	REMC_PSDIV_32	0x0003			// PCLK/32
#define	REMC_PSDIV_24	0x0002			// PCLK/24
#define	REMC_PSDIV_16	0x0001			// PCLK/16
#define	REMC_PSDIV_12	0x0000			// PCLK/12

#define REMC_PS_OFF		0x0000
#define REMC_PS_ON		0x0004

// Interrupt Mask
#define	REMC_INT_ENABLE		0
#define	REMC_INT_DISABLE	1

// Macro function
#define	RemcGetPrescale()		(unsigned char)(REMC_PSC & REMC_PSC_PSDIV)
#define	RemcStartPrescale()		(REMC_PSC |= REMC_PSC_PSON)
#define	RemcStopPrescale()		(REMC_PSC &= ~REMC_PSC_PSON)
#define	RemcStatePrescale()		(REMC_PSC & REMC_PSC_PSON)
#define	RemcSetMode(x)			(REMC_CNF = (REMC_CNF & ~REMC_CNF_MODE) | x)
#define	RemcGetMode()			(REMC_CNF & REMC_CNF_MODE)
#define	RemcEnableUnderflow()	(REMC_CNF = (REMC_CNF & 0xFF8F) | REMC_CNF_UIE)
#define	RemcDisableUnderflow()	(REMC_CNF &= ~(REMC_CNF_UIE | 0x0070))
#define	RemcEnableFalling()		(REMC_CNF = (REMC_CNF & 0xFF8F) | REMC_CNF_FIE)
#define	RemcDisableFalling()	(REMC_CNF &= ~(REMC_CNF_FIE | 0x0070))
#define	RemcEnableRising()		(REMC_CNF = (REMC_CNF & 0xFF8F) | REMC_CNF_RIE)
#define	RemcDisableRising()		(REMC_CNF &= ~(REMC_CNF_RIE | 0x0070))
#define	RemcStartREMC()			(REMC_CTL = REMC_CTL_REMST)
#define	RemcStopREMC()			(REMC_CTL = 0)
#define	RemcSetTransmit(x)		(REMC_ENVL = x)
#define	RemcGetReceive()		(REMC_ENVC)


#ifdef __cplusplus
extern "C" {
#endif

extern void	RemcInit(T_REMC_CFG *);
extern int	RemcTransmit(unsigned char *);
extern int	RemcReceive(unsigned char *);
extern void	RemcInterruptHandler(void);
extern int	RemcSetPrescale(unsigned char);
extern void	RemcSetCarrier(unsigned char, unsigned char);
extern void RemcStop(void);
extern void	RemcInterruptProcess(void);

#ifdef __cplusplus
}
#endif

#endif	/* __REMC_API_H__	*/

