/***************************************************************************
*
*	File name	: sramc_api.h
*	Function	: APIs for SRAMC
*	Revision	:
*		10/03/2007	Nariai		First revision
*
****************************************************************************/
#ifndef	__SRAMC_API_H__
#define	__SRAMC_API_H__

#ifdef	__cplusplus
extern "C" {
#endif


// Device Size
#define	SRAMC_DEV_SIZE_8BIT		0
#define	SRAMC_DEV_SIZE_16BIT	1

// Memory Type
#define	SRAMC_MEM_TYPE_A0		0
#define	SRAMC_MEM_TYPE_BSL		1

// Select EVRAM
#define	SRAMC_EVRAM_CE0			0
#define	SRAMC_EVRAM_CE1			1
#define	SRAMC_EVRAM_CE2			2
#define	SRAMC_EVRAM_CE3			3

// IRAM Wait
#define	SRAMC_IRAM_WAIT_1CYCLE	0
#define	SRAMC_IRAM_WAIT_2CYCLE	1

// MAC Mark Wait
#define	SRAMC_MAC_WAIT_1CYCLE	0
#define	SRAMC_MAC_WAIT_2CYCLE	1


// SRAMC configuration
typedef struct {
	unsigned char		ce0Wait;
	unsigned char		ce1Wait;
	unsigned char		ce2Wait;
	unsigned char		ce3Wait;
	unsigned char		ce0DevSize;
	unsigned char		ce1DevSize;
	unsigned char		ce2DevSize;
	unsigned char		ce3DevSize;
	unsigned char		ce0MemType;
	unsigned char		ce1MemType;
	unsigned char		ce2MemType;
	unsigned char		ce3MemType;
	unsigned char		selEvram;
	unsigned char		iramWait;
	unsigned char		macWait;
	unsigned char		rtcWait;
} T_SRAMC_CFG;


// Macro function

// For external memory static wait control register
#define	SramcSetExtMemWait(x)		(SRAMC_EMSW		= x)
#define	SramcGetExtMemWait()		(SRAMC_EMSW)
#define	SramcSetExtMemWaitCE0(x)	(SRAMC_EMSW		= ((SRAMC_EMSW & ~(SRAMC_EMSW_CE0SW)) | ((x << 0) & SRAMC_EMSW_CE0SW)))
#define	SramcSetExtMemWaitCE1(x)	(SRAMC_EMSW		= ((SRAMC_EMSW & ~(SRAMC_EMSW_CE1SW)) | ((x << 4) & SRAMC_EMSW_CE1SW)))
#define	SramcSetExtMemWaitCE2(x)	(SRAMC_EMSW		= ((SRAMC_EMSW & ~(SRAMC_EMSW_CE2SW)) | ((x << 8) & SRAMC_EMSW_CE2SW)))
#define	SramcSetExtMemWaitCE3(x)	(SRAMC_EMSW		= ((SRAMC_EMSW & ~(SRAMC_EMSW_CE3SW)) | ((x << 12) & SRAMC_EMSW_CE3SW)))
#define	SramcGetExtMemWaitCE0()		(((SRAMC_EMSW & SRAMC_EMSW_CE0SW) >> 0))
#define	SramcGetExtMemWaitCE1()		(((SRAMC_EMSW & SRAMC_EMSW_CE1SW) >> 4))
#define	SramcGetExtMemWaitCE2()		(((SRAMC_EMSW & SRAMC_EMSW_CE2SW) >> 8))
#define	SramcGetExtMemWaitCE3()		(((SRAMC_EMSW & SRAMC_EMSW_CE3SW) >> 12))

// For external memory device size setting register
#define	SramcSetExtMemSize(x)			(SRAMC_EMSZ		= x)
#define	SramcGetExtMemSize()			(SRAMC_EMSZ)
#define	SramcSetExtMemSizeCE0_16Bit()	(SRAMC_EMSZ		|= SRAMC_EMSZ_CE0)
#define	SramcSetExtMemSizeCE0_8Bit()	(SRAMC_EMSZ		&= ~(SRAMC_EMSZ_CE0))
#define	SramcSetExtMemSizeCE1_16Bit()	(SRAMC_EMSZ		|= SRAMC_EMSZ_CE1)
#define	SramcSetExtMemSizeCE1_8Bit()	(SRAMC_EMSZ		&= ~(SRAMC_EMSZ_CE1))
#define	SramcSetExtMemSizeCE2_16Bit()	(SRAMC_EMSZ		|= SRAMC_EMSZ_CE2)
#define	SramcSetExtMemSizeCE2_8Bit()	(SRAMC_EMSZ		&= ~(SRAMC_EMSZ_CE2))
#define	SramcSetExtMemSizeCE3_16Bit()	(SRAMC_EMSZ		|= SRAMC_EMSZ_CE3)
#define	SramcSetExtMemSizeCE3_8Bit()	(SRAMC_EMSZ		&= ~(SRAMC_EMSZ_CE3))

// For external memory type setting register
#define	SramcSetExtMemType(x)			(SRAMC_EMTS		= x)
#define	SramcGetExtMemType()			(SRAMC_EMTS)
#define	SramcSetExtMemTypeCE0_BSL()		(SRAMC_EMTS		|= SRAMC_EMTS_CE0)
#define	SramcSetExtMemTypeCE0_A0()		(SRAMC_EMTS		&= ~(SRAMC_EMTS_CE0))
#define	SramcSetExtMemTypeCE1_BSL()		(SRAMC_EMTS		|= SRAMC_EMTS_CE1)
#define	SramcSetExtMemTypeCE1_A0()		(SRAMC_EMTS		&= ~(SRAMC_EMTS_CE1))
#define	SramcSetExtMemTypeCE2_BSL()		(SRAMC_EMTS		|= SRAMC_EMTS_CE2)
#define	SramcSetExtMemTypeCE2_A0()		(SRAMC_EMTS		&= ~(SRAMC_EMTS_CE2))
#define	SramcSetExtMemTypeCE3_BSL()		(SRAMC_EMTS		|= SRAMC_EMTS_CE3)
#define	SramcSetExtMemTypeCE3_A0()		(SRAMC_EMTS		&= ~(SRAMC_EMTS_CE3))

// For EVRAM select register
#define	SramcSetEvramSel(x)				(SRAMC_EVSEL		= x)
#define	SramcGetEvramSel()				((SRAMC_EVSEL & SRAMC_EVSEL_EVRAM))

// For IRAM read wait setting register
#define	SramcSetIramWait(x)				(SRAMC_IRSW		= x)
#define	SramcGetIramWait()				((SRAMC_IRSW & SRAMC_IRSW_IRAM))

// For MAC mark wait setting register
#define	SramcSetMacMarkWait(x)			(SRAMC_MACW		= x)
#define	SramcGetMacMarkWait()			((SRAMC_MACW & SRAMC_MACW_MACW))

// For RTC wait setting register
#define	SramcSetRtcWait(x)				(SRAMC_RTCW		= x)
#define	SramcGetRtcWait(x)				((SRAMC_RTCW & SRAMC_RTCW_RTCW))


// SRAMC APIs
extern void SramcInit(T_SRAMC_CFG *pConfig);


#ifdef __cplusplus
}
#endif

#endif	// __SRAMC_API_H__

